/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the QtDeclarative module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** No Commercial Usage
** This file contains pre-release code and may not be distributed.
** You may use this file in accordance with the terms and conditions
** contained in the Technology Preview License Agreement accompanying
** this package.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights.  These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
**
**
**
**
**
**
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

import Qt 4.7
import QtMultimediaKit 1.1

FocusScope {

    id: searchView

    property string fromLangShort : TranslateHelper.fromLangShort
    property string toLangShort : TranslateHelper.toLangShort
    property string fromLang : TranslateHelper.fromLang
    property string toLang : TranslateHelper.toLang
    property string fromImage : TranslateHelper.fromImage
    property string toImage : TranslateHelper.toImage
    property alias source : phraseIn.text
    property string speech : ""

    property int margin: 10

    property int transactionState: TranslateHelper.state
    property variant translation: TranslateHelper.translation
    property int transactionMode: 0
    property int modeTranslate: 1
    property int modeSpeech: 2
    property int modeTranslateAndSpeech: 3
    property int modeRecognizeAndTranslate: 4

    property int translationStarted: 0
    property int translationDone: 1
    property int speechStarted: 2
    property int speechDone: 3
    property int recognitionDone: 4
    property int translationError: 5
    property int speechError: 6
    property int recognitionError: 7
    property int audioRecordError: 8

    property bool sourceTextChanged: true

    function closeSoftwareInputPanel() {
        phraseIn.input.closeSoftwareInputPanel()
    }

    onToLangChanged: {
        TranslateHelper.translation = ""
    }

    onFromLangChanged: {
        TranslateHelper.translation = ""
        source = ""
    }

    onTransactionStateChanged: {
        var error = false
        if (transactionState == translationError) {
            errorBar.topic = "Whups, translation error occurred :("
            error = true
        } else if (transactionState == speechError) {
            errorBar.topic = "Whups, speech error occurred :("
            error = true
        } else if (transactionState == speechError) {
            errorBar.topic = "Whups, speech error occurred :("
            error = true
        } else if (transactionState == recognitionError) {
            errorBar.topic = "Whups, speech recognition error occurred :("
            error = true
        } else if (transactionState == audioRecordError) {
            errorBar.topic = "Whups, audio record error occurred :("
            error = true
        }

        if (error) {
            screen.state="searchquery"
            errorAnimation.restart()
            recordTimer.stop()
            return
        }

        if (transactionMode == modeTranslateAndSpeech) {
            if (transactionState === translationDone) {
                if (audio.playing)
                    audio.stop()
                translateAndSpeechTimer.start()
            } else if (transactionState === speechDone) {
                screen.state="searchquery"
                audio.play()
            }
        } else if (transactionMode == modeTranslate) {
            if (transactionState === translationDone) {
                screen.state="searchquery"
            }
        } else if (transactionMode == modeSpeech) {
            if (transactionState === speechDone) {
                screen.state="searchquery"
                audio.play()
            }
        } else if (transactionMode == modeRecognizeAndTranslate) {            
            if (transactionState === recognitionDone) {
                phraseIn.text = TranslateHelper.recognition
                if (phraseIn.text != "") {                    
                    translateTimer.start()
                } else {
                    // TODO: error handling
                    phraseIn.text = "Recognition error. Please, try again and speak better english :)"
                    screen.state="searchquery"
                }
            } else if (transactionState === translationDone) {
                screen.state="searchquery"
            }
        }
    }

    Item {
         Timer {
             id: translateAndSpeechTimer
             interval: 10;
             running: false;
             repeat: false
             onTriggered: {
                 console.log(" translateAndSpeechTimer")
                 stop()
                 TranslateHelper.doTextToSpeech(phraseOut.text, toLangShort);
             }
         }
    }

    Item {
         Timer {
             id: translateTimer
             interval: 10;
             running: false;
             repeat: false
             onTriggered: {
                 stop()
                 TranslateHelper.doTranslate(phraseIn.text, fromLangShort, toLangShort);
             }
         }
    }

    Item {
        Timer {
             id: recordTimer
             interval: 100
             running: false
             repeat: true
             property int startTime: -1
             onTriggered: {
                 if (startTime === -1)
                     startTime = Date.now() / 1000

                 var elapsedTime = Math.round(Date.now() / 1000 - startTime)
                 recordAutomaticEndText.leftTime = 10 - elapsedTime

                 if (elapsedTime >= 10) {
                     stop()
                     TranslateHelper.stopAudioRecord()
                     startTime = -1
                     //recordDimmMouseArea.clicked("") // Same as user stop recording
                     recordItem.visible = false
                 }
             }             
        }
    }

    TitleBar {
        id: errorBar;
        width: parent.width
        height: 80;
        fontColor: "red"
        y: -80

        SequentialAnimation on y {
            id: errorAnimation
            running: false
            NumberAnimation { from: -80; to: 0; duration: 500 }
            PauseAnimation { duration: 3000 }
            NumberAnimation { from: 0; to: -80; duration: 500 }
        }
    }

    Item {
       anchors.horizontalCenter: parent.horizontalCenter
       y: 120
       width:parent.width

        Text {
            id: fromText
            x: margin
            text: "From"
            font.pixelSize: 25;
            font.bold: true; color: "white"; style: Text.Raised; styleColor: "black"            
        }
        Text {
            id: toText
            x: parent.width / 2 + margin / 2
            text: "To"
            font.pixelSize: 25; font.bold: true; color: "white"; style: Text.Raised; styleColor: "black"
            horizontalAlignment: Qt.AlignRight
        }
        LanguageSelector {
            id: fromButton
            width: parent.width / 2 - margin * 1.5
            height: 50
            x: margin
            opacity: 1
            text: fromLang
            source: fromImage
            onClicked: fromButton.doSearch();

            anchors {
                top: fromText.bottom
                topMargin: margin / 2;
            }

            function doSearch() {
                phraseIn.input.closeSoftwareInputPanel()
                titleBar.topic = "Please, select source language"
                languageSelectorListView.model = fromLanguageSelectorListModel
                screen.focus = true;
                screen.state = "fromView"
            }
        }

        LanguageSelector {
            id: toButton
            width: parent.width / 2 - margin
            x: parent.width / 2
            height: 50
            opacity: 1
            text: toLang
            source: toImage
            onClicked: toButton.doSearch();

            anchors {
                top: toText.bottom
                topMargin: 5;
            }

            function doSearch() {
                phraseIn.input.closeSoftwareInputPanel()
                titleBar.topic = "Please, select target language"
                languageSelectorListView.model = toLanguageSelectorListModel
                screen.focus = true;
                screen.state = "toView"
            }
        }

        Text {
            id: sourceText
            x: margin
            text: "Source text"
            font.pixelSize: 25; font.bold: true; color: "white"; style: Text.Raised; styleColor: "black"
            horizontalAlignment: Qt.AlignRight
            anchors {
                top: fromButton.bottom
                left: fromButton.left
                topMargin: margin * 2
            }
        }

        Edit{
            id: phraseIn
            text: ""
            width: parent.width - margin * 2
            height: 150

            anchors {
                top: sourceText.bottom
                topMargin: 5;
                horizontalCenter: parent.horizontalCenter
            }
            onTextChanged: {
                //sourceTextChanged = true
                TranslateHelper.translation = ""
            }
            Image {
                source: "images/mic_button.png"
                width: 48
                height: 48
                visible: TranslateHelper.fromLangRecognitionSupport
                anchors.right: parent.right
                anchors.bottom: parent.bottom
                anchors.bottomMargin: margin
                anchors.rightMargin: margin

                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        phraseIn.input.closeSoftwareInputPanel()
                        console.log("start recording")                        
                        transactionMode = modeRecognizeAndTranslate
                        recordItem.visible = true
                        recordTimer.start()
                        TranslateHelper.startAudioRecord()
                    }
                }
            }
        }

        Button {
            id: translateButton
            width: 150
            height: 50
            x: margin
            opacity: 1
            text: "Translate"

            anchors {
                top: phraseIn.bottom
                topMargin: margin * 2;
            }

            Keys.onReturnPressed: translateButton.doSearch();
            Keys.onEnterPressed: translateButton.doSearch();
            Keys.onSelectPressed: translateButton.doSearch();
            Keys.onSpacePressed: translateButton.doSearch();
            onClicked: translateButton.doSearch();

            function doSearch() {
                phraseIn.input.closeSoftwareInputPanel()
                if (phraseIn.text != "") {
                    transactionMode = modeTranslate
                    screen.state="translate"

                    TranslateHelper.doTranslate(phraseIn.text, fromLangShort, toLangShort);
                }
            }
        }

        Button {
            id: speechButton
            width: 150
            height: 50
            x: margin
            opacity: 1
            text: "Speak"
            visible: TranslateHelper.toLangTtsSupport

            anchors {
                top: phraseIn.bottom
                topMargin: margin * 2;
                right: parent.right
                rightMargin: margin
            }

            Keys.onReturnPressed: translateButton.doSpeech();
            Keys.onEnterPressed: translateButton.doSpeech();
            Keys.onSelectPressed: translateButton.doSpeech();
            Keys.onSpacePressed: translateButton.doSpeech();
            onClicked: speechButton.doSpeech();

            function doSpeech() {
                phraseIn.input.closeSoftwareInputPanel()
                if (phraseOut.text && phraseOut.text.length) {
                    screen.state="translate"
                    if (audio.playing) audio.stop()
                    transactionMode = modeSpeech
                    TranslateHelper.doTextToSpeech(phraseOut.text, toLangShort);
                } else if (phraseIn.text && phraseIn.text.length) {
                    screen.state="translate"
                    transactionMode = modeTranslateAndSpeech
                    TranslateHelper.doTranslate(phraseIn.text, fromLangShort, toLangShort);
                }
            }
        }

        Text {
            id: targetText
            x: margin
            text: "Target text"
            font.pixelSize: 25; font.bold: true; color: "white"; style: Text.Raised; styleColor: "black"
            horizontalAlignment: Qt.AlignRight
            anchors {
                top: translateButton.bottom
                topMargin: margin * 2;
            }
        }
        Edit{
            id: phraseOut
            text: translation
            readOnly: true
            width: parent.width - margin * 2
            height: 150
            isEnabled: false
            anchors {
                top: targetText.bottom
                topMargin: 5;
                horizontalCenter: parent.horizontalCenter
            }
        }

        Audio {
            id: audio
            source: TranslateHelper.speechPath
        }
    }

    Item {
       id: recordItem
       width: screen.width
       height: screen.height
       visible: false
       Rectangle {
           id: recordDimmRectangle
           anchors.fill: parent
           color: "red";
           opacity: 0.4;

           SequentialAnimation on color{
               loops: Animation.Infinite
               running: recordItem.visible
               ColorAnimation { from: "red"; to: "black"; duration: 1000 }
               PauseAnimation { duration: 300 }
               ColorAnimation { from: "black"; to: "red"; duration: 1000 }
           }
           MouseArea {
               id: recordDimmMouseArea
               visible: true
               anchors.fill: parent
               onClicked: {
                   console.log("end recording")
                   recordTimer.stop()
                   recordTimer.startTime = -1 // else timer launch immediately on second run
                   recordItem.visible = false
                   screen.state="translate"
                   TranslateHelper.stopAudioRecordAndDoTranslation()
               }
           }
       }

       Image {
           id: mic
           source: "images/mic_big.png"
           height: 256
           fillMode: Image.PreserveAspectFit
           anchors.horizontalCenter: parent.horizontalCenter
           y: 200
       }

       Text {
           id: touchText
           anchors.top: mic.bottom
           anchors.topMargin: 20
           anchors.horizontalCenter: parent.horizontalCenter
           text: "Speak now!"
           font.pixelSize: 30
           font.bold: true
           color: "#fff"
           style: Text.Raised
           styleColor: "blue"
       }

       Text {
           id: recordAutomaticEndText
           anchors.top: touchText.bottom
           anchors.topMargin: 200
           property int leftTime: 10
           anchors.left: parent.left
           anchors.leftMargin: margin * 4
           anchors.right: parent.right
           anchors.rightMargin: margin * 4
           text: "Touch the screen to stop recognition and start translation. Recording will be canceled in " + leftTime + " s."
           font.pixelSize: 20
           wrapMode: Text.WordWrap
           font.bold: true
           color: "#fff"
           style: Text.Raised
           styleColor: "blue"
       }
   }
}
