/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the QtDeclarative module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** No Commercial Usage
** This file contains pre-release code and may not be distributed.
** You may use this file in accordance with the terms and conditions
** contained in the Technology Preview License Agreement accompanying
** this package.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights.  These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
**
**
**
**
**
**
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

import Qt 4.7
import Qt.labs.particles 1.0
import "TranslatorCore" 1.0 as Translator
//import Qt.multimedia 1.0


Item {
    id: screen
    state:"searchquery"
    width: 480
    height: 854

    property int margin: 10

    function translationChanged(translation){
        screen.state="searchquery"
    }

    Rectangle {
        id: background
        anchors.fill: parent; color: "#7DA2E3";
        state:"searchquery"
        Image {
            source: "TranslatorCore/images/stripes.png";
            fillMode: Image.Tile;
            anchors.fill: parent;
            opacity: 0.3
        }
    }

    MouseArea {
        id: virtualKeyboardCloserLayer
        anchors.fill: parent
        onClicked: { searchView.closeSoftwareInputPanel()}
    }

    Item {
        id: mainView
        width: parent.width        
        height: 460

        Image {
            id: title
            y: 25 //Below the title bars
            source: "TranslatorCore/images/header_logo.png"
            anchors.horizontalCenter: parent.horizontalCenter
            opacity: 0
        }

        Translator.SearchView {
            id: searchView
            //anchors.fill: parent
            width: parent.width;
            height: parent.height-60;
            x: screen.width * 1.5 // animation
        }

//        Particles {
//            id: flag1Anim
//             visible: false
//             y: 150
//             x: 50
//             width: 1
//             height: 1

//             lifeSpan: 3000
//             count: 1
//             emissionRate: 1
//             angle: -20
//             angleDeviation: 20
//             emissionVariance: 0.9
//             velocity: 200
//             velocityDeviation: 100
//             source: "TranslatorCore/images/flags/flag23_" + searchView.fromLangShort + ".png";

//             ParticleMotionGravity {
//                 yattractor: 1000
//                 xattractor: 0
//                 acceleration: 70
//             }
//        }

//        Particles {
//            id: flag2Anim
//             visible: false
//             y: 250
//             x: 50
//             width: 1
//             height: 1

//             lifeSpan: 3000
//             count: 1
//             emissionRate: 1
//             emissionVariance: 0.9
//             angle: -20
//             angleDeviation: 20
//             //emissionVariance: 0.5
//             velocity: 200
//             velocityDeviation: 100
//             source: "TranslatorCore/images/flags/flag23_" + searchView.toLangShort + ".png";
//             ParticleMotionGravity {
//                 yattractor: 1000
//                 xattractor: 0
//                 acceleration: 70
//             }
//        }
    }

    Item {
        id: languageSelectorView
        width: parent.width
        y: 55
        height: 675
        Translator.LanguageModel {
            id: languageModel
        }
        Translator.LanguageDelegate {
            id: languageDelegate
        }

        ListView {
            id: languageSelectorListView;
            delegate: languageDelegate;
            width: parent.width;
            height: parent.height;
            x: 0;
            y: 30;
            cacheBuffer: 100;
        }
    }

    Translator.TitleBar {
        id: titleBar;
        width: parent.width
        height: 80;
    }

    Translator.ToolBar {
        id: toolBar;
        height: 80;
        y: screen.height - 100
        width: parent.width;
        opacity: 0.9
        button1Label: "Back"
        onButton1Clicked:
        {
            screen.state="searchquery"
        }
    }

    // Dimm, spin and eat mouse presses
    Rectangle {
        id: dimm
        width: screen.width
        height: screen.height
        color: "#000000";
        opacity: 0;

        MouseArea {
            id: dimmMouseArea
            visible: false
            anchors.fill: parent
            onClicked: { }
        }
    }

    Translator.Loading {
        id: loading
        anchors.centerIn: parent;
        visible: false
    }

    states: [
        State {
            name: "searchquery";
            PropertyChanges { target: searchView; x: 0}
            PropertyChanges { target: languageSelectorListView; x: -(parent.width * 1.5) }
            PropertyChanges { target: titleBar; y: -80 }
            PropertyChanges { target: toolBar; y: screen.height }
            PropertyChanges { target: toolBar }
            PropertyChanges { target: title; opacity:1}
        },
        State {
            name: "translate";
            PropertyChanges { target: searchView; x: 0}
            PropertyChanges { target: languageSelectorListView; x: -(parent.width * 1.5) }
            PropertyChanges { target: titleBar; y: -80 }
            PropertyChanges { target: toolBar; y: screen.height }
            PropertyChanges { target: toolBar }
            PropertyChanges { target: title; opacity:1}
            PropertyChanges { target: dimm; opacity:0.4}
            PropertyChanges { target: loading; visible: true}
            PropertyChanges { target: dimmMouseArea; visible: true}
        }

    ]
    transitions: [
        Transition { NumberAnimation { properties: "x,y,opacity"; duration: 500; easing.type: Easing.InOutQuad } }
    ]
}
